This function provides a dataset of all organizations, their groups, and
their start and end dates. It covers the period between 1960 and 2005. You
can use this function to access a long dataframe (one observation for each
organization-year dyad), or a wide dataframe (one observation for each
organization, with their start and end years provided in specific columns).