srdp_tactics: Access to SRDP organization-level tactical data.
Description
This function provides a dataset of all SRDP organizations, their groups, the
countries they are challenging, and their yearly use of violent and non-violent
tactics. It covers the period between 1960 and 2005.
Usage
srdp_tactics()
Arguments
Value
A tibble, with each group's facid, name, kgcid, name, country, country challenged, and tactics